==> WiredClient-2.0-2010-06-08.zip: Wired Client.app/Contents/Frameworks/WiredAppKit.framework/Versions/A/Headers/WiredAppKit.h <==
/* $Id: WiredAppKit.h 7767 2009-09-26 14:06:48Z morris $ */

/*
 *  Copyright (c) 2003-2009 Axel Andersson
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#import <WiredAppKit/WIAppKitFunctions.h>

#import <WiredAppKit/WIApplication.h>
#import <WiredAppKit/WIColorCell.h>
#import <WiredAppKit/WICrashReportsController.h>
#import <WiredAppKit/WIExceptionHandler.h>
#import <WiredAppKit/WIGraphView.h>
#import <WiredAppKit/WIIconCell.h>
#import <WiredAppKit/WIImageViewWithImagePicker.h>
#import <WiredAppKit/WIMatrix.h>
#import <WiredAppKit/WIMultiImageCell.h>
#import <WiredAppKit/WIOutlineView.h>
#import <WiredAppKit/WIPreferencesController.h>
#import <WiredAppKit/WIProgressIndicator.h>
#import <WiredAppKit/WIReleaseNotesController.h>
#import <WiredAppKit/WISplitView.h>
#import <WiredAppKit/WITableHeaderView.h>
#import <WiredAppKit/WITableView.h>
#import <WiredAppKit/WITextAttachment.h>
#import <WiredAppKit/WITextView.h>
#import <WiredAppKit/WITreeCell.h>
#import <WiredAppKit/WITreeResizer.h>
#import <WiredAppKit/WITreeScrollView.h>
#import <WiredAppKit/WITreeScroller.h>
#import <WiredAppKit/WITreeTableView.h>
#import <WiredAppKit/WITreeView.h>
#import <WiredAppKit/WIUnclickableProgressIndicator.h>
#import <WiredAppKit/WIWindow.h>
#import <WiredAppKit/WIWindowController.h>

#import <WiredAppKit/NSAlert-WIAppKit.h>
#import <WiredAppKit/NSApplication-WIAppKit.h>
#import <WiredAppKit/NSAttributedString-WIAppKit.h>
#import <WiredAppKit/NSBezierPath-WIAppKit.h>
#import <WiredAppKit/NSColor-WIAppKit.h>
#import <WiredAppKit/NSError-WIAppKit.h>
#import <WiredAppKit/NSEvent-WIAppKit.h>
#import <WiredAppKit/NSFileManager-WIAppKit.h>
#import <WiredAppKit/NSFont-WIAppKit.h>
#import <WiredAppKit/NSImage-WIAppKit.h>
#import <WiredAppKit/NSMenu-WIAppKit.h>
#import <WiredAppKit/NSMenuItem-WIAppKit.h>
#import <WiredAppKit/NSObject-WIAppKit.h>
#import <WiredAppKit/NSPopUpButton-WIAppKit.h>
#import <WiredAppKit/NSSound-WIAppKit.h>
#import <WiredAppKit/NSSplitView-WIAppKit.h>
#import <WiredAppKit/NSTableView-WIAppKit.h>
#import <WiredAppKit/NSTabView-WIAppKit.h>
#import <WiredAppKit/NSTextField-WIAppKit.h>
#import <WiredAppKit/NSTextView-WIAppKit.h>
#import <WiredAppKit/NSToolbar-WIAppKit.h>
#import <WiredAppKit/NSToolbarItem-WIAppKit.h>
#import <WiredAppKit/NSView-WIAppKit.h>
#import <WiredAppKit/NSWindow-WIAppKit.h>
#import <WiredAppKit/NSWindowController-WIAppKit.h>
#import <WiredAppKit/NSWorkspace-WIAppKit.h>

==> WiredClient-2.5-50.zip: Wired Client.app/Contents/Frameworks/WiredAppKit.framework/Versions/A/Headers/WiredAppKit.h <==
/* $Id$ */

/*
 *  Copyright (c) 2003-2009 Axel Andersson
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#import <WiredAppKit/WIAppKitFunctions.h>

#import <WiredAppKit/WIApplication.h>
#import <WiredAppKit/WIChatLogController.h>
#import <WiredAppKit/WIChatHistoryBundle.h>
#import <WiredAppKit/WIColorCell.h>
#import <WiredAppKit/WIConfigManager.h>
#import <WiredAppKit/WICrashReportsController.h>
#import <WiredAppKit/WIEmoticon.h>
#import <WiredAppKit/WIEmoticonPack.h>
#import <WiredAppKit/WIExceptionHandler.h>
#import <WiredAppKit/WIGraphView.h>
#import <WiredAppKit/WIIconCell.h>
#import <WiredAppKit/WIImageViewWithImagePicker.h>
#import <WiredAppKit/WIMatrix.h>
#import <WiredAppKit/WIMultiImageCell.h>
#import <WiredAppKit/WIOutlineView.h>
#import <WiredAppKit/WIPreferencesController.h>
#import <WiredAppKit/WIProgressIndicator.h>
#import <WiredAppKit/WIReleaseNotesController.h>
#import <WiredAppKit/WISheetController.h>
#import <WiredAppKit/WISplitView.h>
#import <WiredAppKit/WIStatusMenuManager.h>
#import <WiredAppKit/WITableHeaderView.h>
#import <WiredAppKit/WITableView.h>
#import <WiredAppKit/WITemplateBundleManager.h>
#import <WiredAppKit/WITemplateBundle.h>
#import <WiredAppKit/WITextAttachment.h>
#import <WiredAppKit/WITextView.h>
#import <WiredAppKit/WITreeCell.h>
#import <WiredAppKit/WITreeResizer.h>
#import <WiredAppKit/WITreeScrollView.h>
#import <WiredAppKit/WITreeScroller.h>
#import <WiredAppKit/WITreeTableView.h>
#import <WiredAppKit/WITreeView.h>
#import <WiredAppKit/WIUnclickableProgressIndicator.h>
#import <WiredAppKit/WIView.h>
#import <WiredAppKit/WIWindow.h>
#import <WiredAppKit/WIWindowController.h>
#import <WiredAppKit/WIDOMElement.h>

#import <WiredAppKit/NSAlert-WIAppKit.h>
#import <WiredAppKit/NSApplication-WIAppKit.h>
#import <WiredAppKit/NSAttributedString-WIAppKit.h>
#import <WiredAppKit/NSBezierPath-WIAppKit.h>
#import <WiredAppKit/NSColor-WIAppKit.h>
#import <WiredAppKit/NSError-WIAppKit.h>
#import <WiredAppKit/NSEvent-WIAppKit.h>
#import <WiredAppKit/NSFileManager-WIAppKit.h>
#import <WiredAppKit/NSFont-WIAppKit.h>
#import <WiredAppKit/NSImage-WIAppKit.h>
#import <WiredAppKit/NSMenu-WIAppKit.h>
#import <WiredAppKit/NSMenuItem-WIAppKit.h>
#import <WiredAppKit/NSObject-WIAppKit.h>
#import <WiredAppKit/NSPopUpButton-WIAppKit.h>
#import <WiredAppKit/NSSound-WIAppKit.h>
#import <WiredAppKit/NSSplitView-WIAppKit.h>
#import <WiredAppKit/NSTableView-WIAppKit.h>
#import <WiredAppKit/NSTabView-WIAppKit.h>
#import <WiredAppKit/NSTextField-WIAppKit.h>
#import <WiredAppKit/NSTextView-WIAppKit.h>
#import <WiredAppKit/NSToolbar-WIAppKit.h>
#import <WiredAppKit/NSToolbarItem-WIAppKit.h>
#import <WiredAppKit/NSTreeController+WIAppKit.h>
#import <WiredAppKit/NSView-WIAppKit.h>
#import <WiredAppKit/NSWindow-WIAppKit.h>
#import <WiredAppKit/NSWindowController-WIAppKit.h>
#import <WiredAppKit/NSWorkspace-WIAppKit.h>
#import <WiredAppKit/WebView-WIAppKit.h>

#import <WiredAppKit/CTBadge.h>
